@@ -14,19 +14,10 @@ use integer;
 	     Metaphone
 );
 
-$VERSION = 1.96;
+$VERSION = '2.00';
 
 bootstrap Text::Metaphone $VERSION;
 
-# I should probably do this in XS, too...
-sub Metaphone {
-    my($word, $len) = @_;
-    my($phoned);
-    $len = 0 unless defined $len;
-    metaphone($word, $len, $phoned);
-    return $phoned;
-}
-
 1;
 
 __END__
